===============================
Kubey
===============================


.. image:: https://img.shields.io/pypi/v/kubey.svg
        :target: https://pypi.python.org/pypi/kubey

.. image:: https://img.shields.io/travis/bradrf/kubey.svg
        :target: https://travis-ci.org/bradrf/kubey

.. image:: https://readthedocs.org/projects/kubey/badge/?version=latest
        :target: https://kubey.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Simple wrapper to help find specific Kubernetes pods and containers and run asynchronous commands.


* Free software: MIT license
* Documentation: https://kubey.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
